..
    Copyright (c) 2018..2020 Bobby Noelte
    SPDX-License-Identifier: Apache-2.0

.. _cogeno_modules_zephyr:

Zephyr support functions
########################

The Zephyr module supports code generation for the Zephyr RTOS.

To use the module in inline code generation import it by:

::

    cogeno.import_module('zephyr')

In case you want to use the Zephyr module in another Python
project import it by:

::

    import cogeno.modules.zephyr


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   zephyr_device_declare
   zephyr_api

